(* TEST
 modules = "f.ml";
*)

exit (if F.Alias = F.alias then 0 else 1)
